# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [
      # Include the results of the hardware scan.
      ./btrbk.nix
      ./hardware-configuration.nix
      ./wireguard.nix
      ./builder.nix
    ];

  # Nix cache
  nix.extraOptions = ''
  secret-key-files = /etc/nix/cache-priv-key.pem
  '';

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.efi.efiSysMountPoint = "/boot/efi";

  # Setup keyfile
  boot.initrd.secrets = {
    "/crypto_keyfile.bin" = null;
    "/keyfile" = null;
  };

  # Enable swap on luks
  boot.initrd.luks.devices."luks-28ea4268-e74a-4ed7-9484-b113c676124e".device = "/dev/disk/by-uuid/28ea4268-e74a-4ed7-9484-b113c676124e";
  boot.initrd.luks.devices."luks-28ea4268-e74a-4ed7-9484-b113c676124e".keyFile = "/crypto_keyfile.bin";

  boot.initrd.luks.devices."cryptdrive4".device = "/dev/disk/by-uuid/d2119824-fe98-449b-9d1b-2ab552568493";
  boot.initrd.luks.devices."cryptdrive4".keyFile = "/keyfile";

  boot.initrd.luks.devices."cryptdrive3".device = "/dev/disk/by-uuid/99dd440d-c6ed-4149-85a1-e8f22a6f2535";
  boot.initrd.luks.devices."cryptdrive3".keyFile = "/keyfile";

  boot.initrd.luks.devices."cryptdrive2".device = "/dev/disk/by-uuid/fd0c26d4-db05-4218-826c-51a87dd39eb5";
  boot.initrd.luks.devices."cryptdrive2".keyFile = "/keyfile";

  boot.initrd.luks.devices."cryptdrive1".device = "/dev/disk/by-uuid/20515efa-5380-4116-946e-7fe527ed3b92";
  boot.initrd.luks.devices."cryptdrive1".keyFile = "/keyfile";

  boot.kernelPackages = pkgs.linuxPackages_latest;

  boot.binfmt.emulatedSystems = [ "aarch64-linux" ];

  fileSystems = {
    "/home/asonix/Development".options = [ "compress=zstd" ];
    "/home/asonix/Diskimages".options = [ "compress=zstd" ];
    "/home/asonix/Documents".options = [ "compress=zstd" ];
    "/home/asonix/Downloads".options = [ "compress=zstd" ];
    "/home/asonix/Games".options = [ "compress=zstd" ];
    "/home/asonix/Games2".options = [ "compress=zstd" ];
    "/home/asonix/Music".options = [ "compress=zstd" ];
    "/home/asonix/Pictures".options = [ "compress=zstd" ];
    "/home/asonix/Videos".options = [ "compress=zstd" ];
  };

  networking.hostName = "firestar"; # Define your hostname.

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  nix.settings.experimental-features = [ "nix-command" "flakes" ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

}
